/**
 * core.js - all global scripts belong in this file.
 */

utils.currentPage = function() {"use strict"
  let curPage = window.location.pathname.substring(
    window.location.pathname.lastIndexOf ('/') + 1
    ).split("?")[0];
  if(!curPage){ curPage = "home" }
  return curPage
};
utils.scrollDistance = function() {
  return document.documentElement.scrollTop;
}
utils.scrollOffset = function() {
  return document.querySelector('#header').offsetHeight;
}
utils.toggleClass = function(selector,className) {
  let thisDiv = document.querySelector(selector);
  if ( thisDiv.classList.contains(className) ){
    thisDiv.classList.remove(className)
  } else {
    thisDiv.classList.add(className)
  }
}
utils.addClass = function(selector,className) {
  let thisDiv = document.querySelector(selector);
  thisDiv.classList.add(className)
}
utils.rmClass = function(selector,className) {
  let thisDiv = document.querySelector(selector);
  thisDiv.classList.remove(className)
}

var rotator = {
  rotate : function (selector, holdTime, fadeTime) {"use strict";
    var thisTimeout;
    var currentSlide = 1;
    var numberOfSlides = document.querySelectorAll(selector).length;
    if(!holdTime) { holdTime = 16000; }
    if(!fadeTime) { fadeTime = 1000; }
    function rotateSlide() {
      if( document.querySelector(selector + ".active") ) {
        document.querySelector(selector + ".active").classList.remove('active');
      }
      setTimeout(function(){
        document.querySelector(selector + ":nth-child("+currentSlide+")").classList.add('active');
      },fadeTime);
      currentSlide++;
      if(currentSlide > numberOfSlides){
        currentSlide = 1;
      }
      if(thisTimeout){clearTimeout(thisTimeout);}
      thisTimeout = setTimeout( rotateSlide, holdTime );
    }
    document.querySelector(selector + ":nth-child("+currentSlide+")").classList.add('active');
    setTimeout(function(){
      rotateSlide();
    },holdTime - (fadeTime/2));
  }
}

var clickHandler = {}
clickHandler.init = function() {"use strict";
  var el = document.querySelector(utils.currentPage());
  if(el){
    el.scrollIntoView({
      behavior: 'smooth' // smooth scroll
    })
  }
  // click handler
  var handled = false;
  function handleClick(e) {
    if(!handled){
      handled = true;
      setTimeout(function(){
        handled=false;
      },200);
      // open and close main menu
      if( e.target.classList.contains('nav-toggle') || e.target.id == 'main-menu' ){
        // if menu is open, close it up
        if(document.body.classList.contains('menu-open')){
          // but only if no sub categories
          if(!e.target.classList.contains('top-level') && !e.target.classList.contains('arrow')){
            setTimeout(function(){
              document.body.classList.remove('menu-open');
              document.getElementById("nav-close").id = "nav-open";
              document.getElementById("nav-open").setAttribute('aria-label', 'open main menu');
              document.getElementById("nav-open").setAttribute('aria-expanded', false);
            }, 100);
            return true;
          }
        // if menu is closed, open it
        } else {
          document.body.classList.add('menu-open');
          document.getElementById("nav-open").id = "nav-close";
          document.getElementById("nav-close").setAttribute('aria-label', 'close main menu');
          document.getElementById("nav-close").setAttribute('aria-expanded', true);
          return true;
        }
      }
      // play video
      if(e.target.classList.contains('custom-thumb')){
        video.play('#video-play');
      }
      // record toggle
      if(e.target.id === "start-stop"){
        let thisDiv = document.querySelector("#bg-record");
        utils.rmClass("#bg-record", "spin");
        utils.addClass("#bg-record", "spin-forever");
        //console.log(thisDiv.style);
        if(thisDiv.style.animationPlayState === "") {
          thisDiv.style.animationPlayState = "running"
        } else if(thisDiv.style.animationPlayState === "paused") {
          thisDiv.style.animationPlayState = "running"
          utils.toggleClass("#bg-record", "paused");
        } else {
          thisDiv.style.animationPlayState = "paused"
          utils.toggleClass("#bg-record", "paused");
        }
      }
      // initialize Spotify player
      if(e.target.classList.contains('listen-button')){
        spotify.init();
      }
    } else {
      return false;
    }
  }
  window.addEventListener('touchstart', handleClick);
  window.addEventListener('click', handleClick);
};

var resizeHandler = {}
resizeHandler.init = function() {"use strict";
  // resize handler
  var handled = false;
  function handleResize(e) {
    if(!handled){
      handled = true;
      setTimeout(function(){
        handled=false;
      },20);
      // open and close main menu
      if( e.target.classList.contains('nav-toggle') || e.target.id == 'main-menu' ){
        // if menu is open, close it up
        if(document.body.classList.contains('menu-open')){
          // but only if no sub categories
          if(!e.target.classList.contains('top-level') && !e.target.classList.contains('arrow')){
            setTimeout(function(){
              document.body.classList.remove('menu-open');
              document.getElementById("nav-close").id = "nav-open";
              document.getElementById("nav-open").setAttribute('aria-label', 'open main menu');
              document.getElementById("nav-open").setAttribute('aria-expanded', false);
            }, 100);
            return true;
          }
        // if menu is closed, open it
        } else {
          document.body.classList.add('menu-open');
          document.getElementById("nav-open").id = "nav-close";
          document.getElementById("nav-close").setAttribute('aria-label', 'close main menu');
          document.getElementById("nav-close").setAttribute('aria-expanded', true);
          return true;
        }
      }
      // play video
      if(e.target.classList.contains('custom-thumb')){
        video.play('#video-play');
      }
      // initialize Spotify player
      if(e.target.classList.contains('listen-button')){
        spotify.init();
      }
    } else {
      return false;
    }
  }
  function debounce(func){
    var timer;
    return function(event){
      if(timer) clearTimeout(timer);
      timer = setTimeout(func,10,event);
    };
  }
  window.addEventListener("resize",debounce(function(e){
    handleResize();
  }));
};

var scrollHandler = {}
scrollHandler.init = function(){ "use strict"
  // handles scroll events for the page
  function handleScroll() {
    // for home page only
    if(document.body.classList.contains('home')){
      // show and hide listen button
      /*if( utils.scrollDistance() < eval(document.getElementById('title').offsetTop - utils.scrollOffset() ) ){
        document.getElementById("btn-listen").classList.remove("active");
      } else {
        document.getElementById("btn-listen").classList.add("active");
      }*/
    }
    // parallax
    /*if(document.querySelector('.parallax-image')){
      const parallaxImage = document.querySelector('.parallax-image');
      const offsetY = utils.scrollDistance() / 3.7; // Adjust the factor for the parallax effect
      parallaxImage.style.transform = `translate3d(0, ${offsetY}px, 0)`;
    }*/
  }
  function debounce(func){
    var timer;
    return function(event){
      if(timer) clearTimeout(timer);
      timer = setTimeout(func,10,event);
    };
  }
  window.addEventListener("scroll",debounce(function(e){
    handleScroll();
  }));
};

var video = {};
video.loop = function(videoSelector,numberOfTimes) {
  var iterations = 0;
  let myVideo = document.querySelector(videoSelector);
  myVideo.addEventListener("ended", (event) => { 
    if (iterations < numberOfTimes) {       
      myVideo.currentTime = 0;
      myVideo.play();
      iterations ++;
    }
  });
  setTimeout(function(){
    myVideo.classList.add('fade-out');
  },9000);
}

var rotator = {
  rotate : function (selector, holdTime, fadeTime) {"use strict";
    var thisTimeout;
    var currentSlide = 1;
    var numberOfSlides = document.querySelectorAll(selector).length;
    if(!holdTime) { holdTime = 3500; }
    if(!fadeTime) { fadeTime = 1000; }
    function rotateSlide() {
      if( document.querySelector(selector + ".active") ) {
        document.querySelector(selector + ".active").classList.remove('active');
      }
      setTimeout(function(){
        document.querySelector(selector + ":nth-child("+currentSlide+")").classList.add('active');
      },fadeTime);
      currentSlide++;
      if(currentSlide > numberOfSlides){
        currentSlide = 1;
      }
      if(thisTimeout){clearTimeout(thisTimeout);}
      thisTimeout = setTimeout( rotateSlide, holdTime );
    }
    document.querySelector(selector + ":nth-child("+currentSlide+")").classList.add('active');
    setTimeout(function(){
      rotateSlide();
    },holdTime - (fadeTime/2));
  }
}
$(document).ready(function(){
  document.documentElement.classList.add('page-loaded');
  clickHandler.init();
  scrollHandler.init();
  
  if (utils.currentPage() === 'home') {
    //optin.validate();
    rotator.rotate('ul#quote-rotator li', 8000, 1000);
  }
});